@@ -19,15 +19,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
-#include <glib/gi18n.h>
-#include <gtk/gtk.h>
-#include <glade/glade.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
-GladeXML*
-gmp_util_load_glade_file (const char *filename,
-                          const char *widget_root,
-                          GtkWindow  *error_dialog_parent);
+#include <gtk/gtk.h>
+
+GtkBuilder *
+gmp_util_load_builder_file (const char *filename,
+			    GtkWindow  *error_dialog_parent,
+			    GError **error);
 
 void
 gmp_util_show_error_dialog (GtkWindow *transient_parent,
@@ -37,11 +38,3 @@ gmp_util_show_error_dialog (GtkWindow *transient_parent,
 void
 gmp_util_run_error_dialog (GtkWindow *transient_parent,
                            const char *message_format, ...);
-
-#ifdef DEBUG
-#define GMP_DEBUG(...) G_STMT_START{ \
-  { g_print ("DEBUG: "); g_print (__VA_ARGS__); } \
-  } G_STMT_END
-#else
-#define GMP_DEBUG(...)
-#endif
